@@ -35,8 +35,8 @@ class _Attributes:
         """
         self.__space = space
         self.__qubits = qubits
-        self.__max_energy = 100
-        self.__cur_energy = self.__max_energy
+        self.__cur_energy = 1000
+        self.__max_energy = 1000
 
     @property
     def is_alive(self) -> bool:
