@@ -506,7 +506,7 @@ class QrogueCUI(py_cui.PyCUI):
         self.__state_machine.change_state(State.Spaceship, None)
 
     def __won_tutorial(self) -> None:
-        self.switch_to_menu(None)   # todo adapt
+        self.switch_to_menu(None)
         bell = ColorConfig.highlight_word("Bell")
         Popup.message("You won!", f"Congratulations, you defeated {bell} and successfully played the Tutorial!")
 
